from flask import Flask, render_template, Response

from indication_driver import IndicationDriver
from camera_driver import CameraDriver
import config

app = Flask(__name__)

indication_driver = IndicationDriver()
camera_driver = CameraDriver()

def stream():
    global indication_driver
    global camera_driver
    last_codes = []
    while True:
        jpg, codes = camera_driver.get_decoded_frame(400, 800)
        if codes and not (set(codes) & set(last_codes)):
            print(codes)
            trash_category = None
            known_code = None
            for code in codes:
                known_code = code if code in config.BARCODE_LOOKUP_TABLE.keys() else known_code
            if known_code:
                trash_category = config.BARCODE_LOOKUP_TABLE[known_code]
                indication_driver.indicate(trash_category)
            else:
                indication_driver.stop()
            last_codes = codes
        yield b'--frame\r\nContent-Type: image/jpeg\r\n\r\n' + jpg + b'\r\n\r\n'

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/stream_feed')
def stream_feed():
    return Response(stream(), mimetype='multipart/x-mixed-replace; boundary=frame')

if __name__ == '__main__':
    app.run(debug=False, port=5000, host='0.0.0.0')
